#!/usr/bin/env python
# -*- coding: utf-8 -*-
# File: mode/test_trader.py
# Author: Jimin Huang <huangjimin@whu.edu.cn>
# Date: 26.09.2017


class Trader(object):
    """Class for testing
    """
    def __init__(self, arguments):
        pass

    def get_account(self):
        """Test method for ``get_account``
        """
        return 'test'
